package net.surguy.logfilter;

import org.apache.log4j.Category;

/**
 * Class that does logging - to be tested by LogPreloaderTest.
 *
 * @author Inigo Surguy
 * @created 08-Feb-2004 16:05:25
 */
public class DoesLogging {
    private static final Category logger = Category.getInstance("net.surguy.logfilter.DoesLogging");

    void simpleLogAtDebug() {
        logger.debug("simpleLogAtDebug");
    }

    void simpleLogAtInfo() {
        logger.info("simpleLogAtInfo");
    }

    public void simpleLogAtWarn() {
        logger.warn("simpleLogAtWarn");
    }


    void debugThenInfo() {
        logger.debug("debugThenInfo");
        logger.info("debugThenInfo");
    }

    String returnString() {
        String s = "returnString";
        logger.debug("returnString");
        return s;
    }

    String returnStringWithInfo() {
        String s = "returnStringWithInfo";
        logger.info("returnStringWithInfo");
        return s;
    }

    void categoryGetRoot() {
        Category.getRoot();
        logger.info("categoryGetRoot");
    }

    String categoryGetRootViaInstance() {
        String rootName = logger.getRoot().getName();
        logger.info("categoryGetRootViaInstance");
        return rootName;
    }

    String categoryGetRootViaInstanceWithDebug() {
        String s = "temporary";
        logger.debug("Doing some debugging");
        logger.getRoot();
        s = "categoryGetRootViaInstanceWithDebug";
        logger.info("categoryGetRootViaInstanceWithDebug");
        return s;
    }

    int doMathsBetweenDebugs(int i, int i2) {
        logger.debug("Starting with "+i+" and "+i2+" making "+(i+12));
        int i3 = i * i2;
        logger.debug("As objects they are " + new Integer(i) + " and " + new Integer(i2));
        logger.info("doMathsBetweenDebugs with "+i+" and "+i2);
        return i3 - i;
    }

    void debugLogCallInsideLog() {
        logger.debug("Logger name is " + logger.getRoot().getName()+".");
    }

    void infoLogCallInsideLog() {
        logger.info("Logger name is " + logger.getRoot().getName()+".");
    }

    void localInnerClass() {
        class LocalInnerLogger {
            void doInnerLogging() {
                logger.debug("LocalInnerLogger");
                logger.info("LocalInnerLogger");
            }
        }
        new LocalInnerLogger().doInnerLogging();
    }

    void staticInnerClass() {
        new StaticInnerClass().doStaticInnerLogging();
    }

    static class StaticInnerClass {
        void doStaticInnerLogging() {
            logger.debug("StaticInnerLogger");
            logger.info("StaticInnerLogger");
        }
    }

    void memberInnerClass() {
        new MemberInnerClass().doMemberInnerLogging();
    }

    class MemberInnerClass {
        void doMemberInnerLogging() {
            logger.debug("MemberInnerLogger");
            logger.info("MemberInnerLogger");
        }
    }

    void anonymousInnerClass() {
        Object o = new Object() {
            public String toString() {
                logger.debug("AnonymousInnerLogger");
                logger.info("AnonymousInnerLogger");
                return "Anonymous";
            }
        };
        o.toString();
    }


}
